@@ -26,10 +26,13 @@ def getCoursesTaken(html):
     courses = []
     for i in range(len(html_text)):
         if (len(html_text[i]) == 4 and isAllCaps(html_text[i]) and 
-            len(html_text[i+1]) == 4 and html_text[i+1].isdigit() and 
-            not html_text[i+5] in ("F", "NC", "U", "W")):
+            len(html_text[i+1]) == 4 and html_text[i+1].isdigit() and not
+            set([html_text[i+5], html_text[i+6]]).issubset(["F", "NC", "U", "W"]):
 	    name = html_text[i]+" "+html_text[i+1]
-            term = html_text[i+4]
+            if len(html_text[i+4]) == 6:
+                term = html_text[i+4]
+            else:
+                term = html_text[i+5]
             courses.append(Course(name, term))
     return courses
     
